@@ -4,7 +4,7 @@ package App::SFDC::Deploy;
 use strict;
 use warnings;
 
-our $VERSION = '0.10'; # TRIAL VERSION
+our $VERSION = '0.11'; # TRIAL VERSION
 
 use Data::Dumper;
 use File::Find 'find';
@@ -143,7 +143,7 @@ sub execute {
     my $self = shift;
     unless (scalar @{$self->files}) {
         INFO "Nothing to deploy; exiting";
-        return;
+        return 1; # truthy
     }
     print $self->_result;
     $self->_JUnitOutput;
@@ -162,7 +162,7 @@ App::SFDC::Deploy - Deploy files to SFDC
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 OPTIONS
 
